@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Type::Registry::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Registry::VERSION   = '1.008002';
+	$Type::Registry::VERSION   = '1.008004';
 }
 
 $Type::Registry::VERSION =~ tr/_//d;
@@ -168,14 +168,36 @@ sub simple_lookup
 	my ($tc) = @_;
 	$tc =~ s/(^\s+|\s+$)//g;
 	
-	if (exists $self->{$tc})
-	{
+	if (exists $self->{$tc}) {
 		return $self->{$tc};
 	}
+	elsif ($self->has_parent) {
+		return $self->get_parent->simple_lookup(@_);
+	}
 	
 	return;
 }
 
+sub set_parent {
+	my $self = shift;
+	$self->{'~~parent'} = ref($_[0]) ? $_[0] : (ref($self)||$self)->for_class($_[0]);
+	$self;
+}
+
+sub clear_parent {
+	my $self = shift;
+	delete $self->{'~~parent'};
+	$self;
+}
+
+sub has_parent {
+	!!ref(shift->{'~~parent'});
+}
+
+sub get_parent {
+	shift->{'~~parent'};
+}
+
 sub foreign_lookup
 {
 	my $self = shift;
@@ -472,6 +494,11 @@ Overloaded to call C<lookup>.
 
    $registry->Str;  # like $registry->lookup("Str")
 
+=item C<get_parent>, C<< set_parent($reg) >>, C<< clear_parent >>, C<< has_parent >>
+
+Advanced stuff. Allows a registry to have a "parent" registry which it
+inherits type constraints from.
+
 =back
 
 =head2 Functions
@@ -500,7 +527,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2019 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
