@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY   = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION     = '1.008002';
+	$Type::Tiny::VERSION     = '1.008004';
 	$Type::Tiny::XS_VERSION  = '0.016';
 }
 
@@ -847,7 +847,7 @@ sub inline_check
 			unless $self->has_parent;
 		$r[0] = $self->parent->inline_check(@_);
 	}
-	my $r = join " && " => map { /[;{}]/ && !/\Ado \{.+\}\z/ ? "do { $_ }" : "($_)" } @r;
+	my $r = join " && " => map { /[;{}]/ && !/\Ado \{.+\}\z/ ? "do { package Type::Tiny; $_ }" : "($_)" } @r;
 	return @r==1 ? $r : "($r)";
 }
 
@@ -891,8 +891,8 @@ sub inline_assert
 	}
 	
 	$do_wrapper
-		? qq[do { no warnings "void"; $inline_check or $inline_throw; $varname };]
-		: qq[     no warnings "void"; $inline_check or $inline_throw; $varname   ]
+		? qq[do { no warnings "void"; package Type::Tiny; $inline_check or $inline_throw; $varname };]
+		: qq[     no warnings "void"; package Type::Tiny; $inline_check or $inline_throw; $varname   ]
 }
 
 sub _failed_check {
@@ -946,10 +946,10 @@ sub is_parameterized
 	my %seen;
 	sub ____make_key {
 		join ',', map {
-			Types::TypeTiny::TypeTiny->check($_) ? sprintf('$Type::Tiny::ALL_TYPES{%d}', $_->{uniq}) :
-			ref() eq 'ARRAY'                     ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('[%s]', ____make_key(@$_)) } :
-			ref() eq 'HASH'                      ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('{%s}', ____make_key(%$_)) } :
-			ref() eq 'SCALAR' || ref() eq 'REF'  ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('do { my $x = %s; \\$x }', ____make_key($$_)) } :
+			Types::TypeTiny::TypeTiny->check($_) ? sprintf('$Type::Tiny::ALL_TYPES{%d}', defined($_->{uniq}) ? $_->{uniq} : '____CANNOT_KEY____') :
+			ref() eq 'ARRAY'                     ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('[%s]',   ____make_key(@$_)) } :
+			ref() eq 'HASH'                      ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('{%s}',   ____make_key(%$_)) } :
+			ref() eq 'SCALAR' || ref() eq 'REF'  ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('\\(%s)', ____make_key($$_)) } :
 			!defined()                           ? 'undef' :
 			!ref()                               ? do { require B; B::perlstring($_) } :
 			'____CANNOT_KEY____';
@@ -2230,7 +2230,7 @@ Thanks to Matt S Trout for advice on L<Moo> integration.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2019 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
