@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.008002';
+our $VERSION   = '1.008004';
 
 $VERSION =~ tr/_//d;
 
@@ -284,7 +284,13 @@ sub _TypeTinyFromMoose
 			_TypeTinyFromMoose($paramd);
 		};
 	}
-
+	
+	# Cowardly refuse to inline types that need to close over stuff
+	if ($opts{inlined}) {
+		my %env = %{ $t->inline_environment || {} };
+		delete($opts{inlined}) if keys %env;
+	}
+	
 	require Type::Tiny;
 	my $new = 'Type::Tiny'->new(%opts);
 	$ttt_cache{ refaddr($t) } = $new;
@@ -591,7 +597,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2019 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
